@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2001-2017 Mathew A. Nelson and Robocode contributors
+ * Copyright (c) 2001-2018 Mathew A. Nelson and Robocode contributors
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -93,7 +93,6 @@ public class JarJarURLConnection extends URLConnection {
 			return -1;
 		}
 
-		@SuppressWarnings({ "deprecation"})
 		protected void parseURL(URL url, String spec,
 				int start, int limit) {
 			String file = null;
@@ -132,7 +131,7 @@ public class JarJarURLConnection extends URLConnection {
 				file = toBangSlash + afterBangSlash;
 			}
 			file = file != null ? "jar:" + file.replaceFirst("\\" + SEPARATOR, "!/") : null;
-			setURL(url, "jarjar", "", -1, file, ref);
+			setURL(url, "jarjar", "", -1, null, null, file, null, ref);
 		}
 
 		private String parseAbsoluteSpec(String spec) {
