@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2001-2017 Mathew A. Nelson and Robocode contributors
+ * Copyright (c) 2001-2018 Mathew A. Nelson and Robocode contributors
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -290,21 +290,17 @@ public class RobotItem extends RobotSpecItem implements IRobotItem {
 			if (force) {
 				isValid = true;
 			}
-
-			// trying to guess all correct file locations
-			populate();
-
+			if (isValid) {
+				validateType(false);
+			}
 			this.lastModified = lastModified;
 			if (classURL == null) {
 				isValid = false;
 			}
 			loadProperties();
-			if (root.isJAR() && !isPropertiesLoaded) {
+			if (!isTeamRobot() && root.isJAR() && !isPropertiesLoaded) {
 				isValid = false;
 			}
-			if (isValid) {
-				validateType(false);
-			}
 			if (isValid) {
 				verifyName();
 			}
