@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2001-2017 Mathew A. Nelson and Robocode contributors
+ * Copyright (c) 2001-2018 Mathew A. Nelson and Robocode contributors
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -43,7 +43,7 @@ public interface IWindowManagerExt extends IWindowManager {
 
 	void showGoogleGroupRobocode();
 
-	void showRobocodeRepository();
+	void showRoboRumble();
 
 	void showOptionsPreferences();
 
