@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2001-2017 Mathew A. Nelson and Robocode contributors
+ * Copyright (c) 2001-2018 Mathew A. Nelson and Robocode contributors
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -250,7 +250,7 @@ public class WindowManager implements IWindowManagerExt {
 	}
 
 	public void showJavaDocumentation() {
-		showInBrowser("http://docs.oracle.com/javase/6/docs/api/");
+		showInBrowser("https://docs.oracle.com/javase/8/docs/api/");
 	}
 
 	public void showRobocodeHome() {
@@ -265,8 +265,8 @@ public class WindowManager implements IWindowManagerExt {
 		showInBrowser("https://groups.google.com/forum/?fromgroups#!forum/robocode");
 	}
 
-	public void showRobocodeRepository() {
-		showInBrowser("http://robocoderepository.com");
+	public void showRoboRumble() {
+		showInBrowser("http://robowiki.net/wiki/RoboRumble");
 	}
 
 	public void showOptionsPreferences() {
