@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2001-2017 Mathew A. Nelson and Robocode contributors
+ * Copyright (c) 2001-2018 Mathew A. Nelson and Robocode contributors
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -849,7 +849,7 @@ public class RobocodeFrame extends JFrame {
 					final boolean attach = index < RobotDialogManager.MAX_PRE_ATTACHED;
 					final RobotButton button = net.sf.robocode.core.Container.createComponent(RobotButton.class);
 
-					button.setup(robot.getName(), maxEnergy, index, robot.getContestantIndex(), attach);
+					button.setup(robot.getName(), maxEnergy, index, robot.getContestantIndex(), robot.getTeamIndex(), attach);
 					button.setText(robot.getShortName());
 					addRobotButton(button);
 				}
